
"""Top-level package for cloudtipsadp API Python Client Library."""
from cloudtipsadp.accumulations import Accumulations
from cloudtipsadp.cards import Cards
from cloudtipsadp.clients import Connect, ProductClient, SandboxClient
from cloudtipsadp.configuration import Configuration, Token
from cloudtipsadp.places import Places
from cloudtipsadp.receivers import Receivers

__author__ = "SETTER"
__email__ = 'lphp@mail.ru'
